#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-BXdyiVyEfiUAXJOt1dBT1i
key:                  pantry-0.8.3-BXdyiVyEfiUAXJOt1dBT1i
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  eb4f5e50d33c535a375d3b1fff4a94c9
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-BXdyiVyEfiUAXJOt1dBT1i
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-4XfhhWkmpwnB2gRUwfJP7g
    ansi-terminal-1.1-ceWtUmn4Pxa80ZJp3NGJ base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-BnMH4YtIClA6c5qmLKdMrJ
    casa-types-0.0.3-A5UNB8dpvP8DdzIkQ1uXrM
    conduit-1.3.6.1-J8ndGOkTyJX5j6RwH3LErP
    conduit-extra-1.3.8-1MJDSKZWOFdD8JdSNAsA5D containers-0.6.7
    crypton-1.0.4-DUIjSH5Fjd7IDpQXBny8mu
    crypton-conduit-0.2.3-DjhVQeLSo9S1Ml48xYOUqO
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-2NuenGjZGEP9gjjd1HBwTe
    generic-deriving-1.14.7-EdpMS6VUjSWAYwhkxCiLC8
    hackage-security-0.6.3.2-8T2ZNiyj1mp7hrPp7gRH1J
    hpack-0.38.0-C5Z9r1HbrzIB4uXiDcmmlL
    http-client-0.7.19-5W0pzTITYjpFV1kzozadf
    http-client-tls-0.3.6.4-2purl0gjnwFafpzSyiSHH
    http-conduit-2.3.9.1-J3ZuAne4JY36DPznNMquNP
    http-download-0.2.1.0-34gADcA1Tw7GAFYJ8CfKhS
    http-types-0.12.4-5vT9XdIpLUEBOtUXM3tA09
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-CMtdZ463jfq9hso9AZHHZa
    path-0.9.6-KaxN0p2mS267h4V2rQaqka
    path-io-1.8.2-CpFSfNghipGCmfixlgjGc1
    persistent-2.14.6.0-JAjb2qYOThL5Wvc8hdouPf
    persistent-sqlite-2.13.2.0-4aMdRx7tYJFJ1ueOkv8VbW
    primitive-0.9.1.0-97PnMKvcoehIZjLlTXPCZe
    resourcet-1.3.0-BrdZatkp6QIII6Vs5RqUd1
    rio-0.1.24.0-1VGf2VAGB4oIEaDhLDTe6Y
    rio-orphans-0.1.2.0-3s7U5ohW2MEGB2KodWDiOs
    rio-prettyprint-0.1.8.0-11OKrevxvoE3T5mJWMHFKF
    tar-conduit-0.4.1-LQI67G24CgXCoZwxXVbVrc text-2.0.2
    text-metrics-0.3.3-GMnvyHxgcHDErZUEWUIgk8 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-BrtbnxVKHC78wxaaRdMitr
    unliftio-0.2.25.1-E7jBNjB3KP6CTth0IZkvqw
    unordered-containers-0.2.20.1-3DXXOqLpcMZGFktSBwG2cs
    vector-0.13.2.0-7HrFQCkgeKZFLrimW7Ifgg
    yaml-0.11.11.2-58WeWnkZTUG9e3PdNR129q
    zip-archive-0.4.3.2-Du0FDRjTLYF5KVtFwcE7TQ

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

